@@ -13,9 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import monasca_common.validation.metrics as metric_validator
-from six.moves import range
-import unittest
+from oslotest import base
+import six
+
+from monasca_common.validation import metrics as metric_validator
 
 # a few valid characters to test
 valid_name_chars = ".'_-"
@@ -26,7 +27,7 @@ valid_dimension_chars = " .'_-"
 invalid_dimension_chars = "<>={}(),\"\\\\;&"
 
 
-class TestMetricValidation(unittest.TestCase):
+class TestMetricValidation(base.BaseTestCase):
     def test_valid_single_metric(self):
         metric = {"name": "test_metric_name",
                   "dimensions": {"key1": "value1",
@@ -55,19 +56,19 @@ class TestMetricValidation(unittest.TestCase):
     def test_valid_metric_unicode_dimension_value(self):
         metric = {"name": "test_metric_name",
                   "timestamp": 1405630174123,
-                  "dimensions": {unichr(2440): 'B', 'B': 'C', 'D': 'E'},
+                  "dimensions": {six.unichr(2440): 'B', 'B': 'C', 'D': 'E'},
                   "value": 5}
         metric_validator.validate(metric)
 
     def test_valid_metric_unicode_dimension_key(self):
         metric = {"name": 'test_metric_name',
-                  "dimensions": {'A': 'B', 'B': unichr(920), 'D': 'E'},
+                  "dimensions": {'A': 'B', 'B': six.unichr(920), 'D': 'E'},
                   "timestamp": 1405630174123,
                   "value": 5}
         metric_validator.validate(metric)
 
     def test_valid_metric_unicode_metric_name(self):
-        metric = {"name": unichr(6021),
+        metric = {"name": six.unichr(6021),
                   "dimensions": {"key1": "value1",
                                  "key2": "value2"},
                   "timestamp": 1405630174123,
@@ -288,7 +289,7 @@ class TestMetricValidation(unittest.TestCase):
 
     def test_invalid_too_many_value_meta(self):
         value_meta = {}
-        for i in range(0, 17):
+        for i in six.moves.range(0, 17):
             value_meta['key{}'.format(i)] = 'value{}'.format(i)
         metric = {"name": "test_metric_name",
                   "dimensions": {"key1": "value1",
@@ -315,7 +316,7 @@ class TestMetricValidation(unittest.TestCase):
 
     def test_invalid_too_long_value_meta_key(self):
         key = "K"
-        for i in range(0, metric_validator.VALUE_META_NAME_MAX_LENGTH):
+        for i in six.moves.range(0, metric_validator.VALUE_META_NAME_MAX_LENGTH):
             key = "{}{}".format(key, "1")
         value_meta = {key: 'BBB'}
         metric = {"name": "test_metric_name",
@@ -332,10 +333,10 @@ class TestMetricValidation(unittest.TestCase):
     def test_invalid_too_large_value_meta(self):
         value_meta_value = ""
         num_value_meta = 10
-        for i in range(0, metric_validator.VALUE_META_VALUE_MAX_LENGTH / num_value_meta):
+        for i in six.moves.range(0, int(metric_validator.VALUE_META_VALUE_MAX_LENGTH / num_value_meta)):
             value_meta_value = '{}{}'.format(value_meta_value, '1')
         value_meta = {}
-        for i in range(0, num_value_meta):
+        for i in six.moves.range(0, num_value_meta):
             value_meta['key{}'.format(i)] = value_meta_value
         metric = {"name": "test_metric_name",
                   "dimensions": {"key1": "value1",
@@ -374,7 +375,7 @@ class TestMetricValidation(unittest.TestCase):
              "timestamp": 1405630174123,
              "value": 2.0}
         ]
-        for i in range(len(metrics)):
+        for i in six.moves.range(len(metrics)):
             metric_validator.validate_name(metrics[i]['name'])
             metric_validator.validate_value(metrics[i]['value'])
             metric_validator.validate_timestamp(metrics[i]['timestamp'])
